"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useMetaBoxInitialization = void 0;
var _data = require("@wordpress/data");
var _editor = require("@wordpress/editor");
var _element = require("@wordpress/element");
var _store = require("../../store");
/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */

/**
 * Initializes WordPress `postboxes` script and the logic for saving meta boxes.
 *
 * @param { boolean } enabled
 */
const useMetaBoxInitialization = enabled => {
  const isEnabledAndEditorReady = (0, _data.useSelect)(select => enabled && select(_editor.store).__unstableIsEditorReady(), [enabled]);
  const {
    initializeMetaBoxes
  } = (0, _data.useDispatch)(_store.store);
  // The effect has to rerun when the editor is ready because initializeMetaBoxes
  // will noop until then.
  (0, _element.useEffect)(() => {
    if (isEnabledAndEditorReady) {
      initializeMetaBoxes();
    }
  }, [isEnabledAndEditorReady, initializeMetaBoxes]);
};
exports.useMetaBoxInitialization = useMetaBoxInitialization;
//# sourceMappingURL=use-meta-box-initialization.js.map