"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MetaBoxesSection = MetaBoxesSection;
exports.default = void 0;
var _i18n = require("@wordpress/i18n");
var _data = require("@wordpress/data");
var _editor = require("@wordpress/editor");
var _preferences = require("@wordpress/preferences");
var _enableCustomFields = _interopRequireDefault(require("./enable-custom-fields"));
var _enablePanel = _interopRequireDefault(require("./enable-panel"));
var _store = require("../../store");
var _lockUnlock = require("../../lock-unlock");
var _jsxRuntime = require("react/jsx-runtime");
/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */

const {
  PreferencesModalSection
} = (0, _lockUnlock.unlock)(_preferences.privateApis);
function MetaBoxesSection({
  areCustomFieldsRegistered,
  metaBoxes,
  ...sectionProps
}) {
  // The 'Custom Fields' meta box is a special case that we handle separately.
  const thirdPartyMetaBoxes = metaBoxes.filter(({
    id
  }) => id !== 'postcustom');
  if (!areCustomFieldsRegistered && thirdPartyMetaBoxes.length === 0) {
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(PreferencesModalSection, {
    ...sectionProps,
    children: [areCustomFieldsRegistered && /*#__PURE__*/(0, _jsxRuntime.jsx)(_enableCustomFields.default, {
      label: (0, _i18n.__)('Custom fields')
    }), thirdPartyMetaBoxes.map(({
      id,
      title
    }) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_enablePanel.default, {
      label: title,
      panelName: `meta-box-${id}`
    }, id))]
  });
}
var _default = exports.default = (0, _data.withSelect)(select => {
  const {
    getEditorSettings
  } = select(_editor.store);
  const {
    getAllMetaBoxes
  } = select(_store.store);
  return {
    // This setting should not live in the block editor's store.
    areCustomFieldsRegistered: getEditorSettings().enableCustomFields !== undefined,
    metaBoxes: getAllMetaBoxes()
  };
})(MetaBoxesSection);
//# sourceMappingURL=meta-boxes-section.js.map